import { Http,Util } from '@/utils';
import EntityService from '../entity-service';



/**
 * 员工服务对象基类
 *
 * @export
 * @class HREmployeeServiceBase
 * @extends {EntityServie}
 */
export default class HREmployeeServiceBase extends EntityService {

    /**
     * Creates an instance of  HREmployeeServiceBase.
     * 
     * @param {*} [opts={}]
     * @memberof  HREmployeeServiceBase
     */
    constructor(opts: any = {}) {
        super(opts);
    }

    /**
     * 初始化基础数据
     *
     * @memberof HREmployeeServiceBase
     */
    public initBasicData(){
        this.APPLYDEKEY ='hremployee';
        this.APPDEKEY = 'employeeid';
        this.APPDENAME = 'hremployees';
        this.APPDETEXT = 'employeename';
        this.APPNAME = 'pim';
        this.SYSTEMNAME = 'ibizhumanresources';
    }

// 实体接口

    /**
     * Select接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HREmployeeServiceBase
     */
    public async Select(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            let res:any = Http.getInstance().get(`/hremployees/${context.hremployee}/select`,isloading);
            
            return res;
    }

    /**
     * Create接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HREmployeeServiceBase
     */
    public async Create(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let masterData:any = {};
        Object.assign(data,masterData);
        if(!data.srffrontuf || data.srffrontuf !== "1"){
            data[this.APPDEKEY] = null;
        }
        if(data.srffrontuf){
            delete data.srffrontuf;
        }
        let tempContext:any = JSON.parse(JSON.stringify(context));
        let res:any = await Http.getInstance().post(`/hremployees`,data,isloading);
        this.tempStorage.setItem(tempContext.srfsessionkey+'_hrarchives',JSON.stringify(res.data.hrarchives?res.data.hrarchives:[]));
        this.tempStorage.setItem(tempContext.srfsessionkey+'_hrcertificates',JSON.stringify(res.data.hrcertificates?res.data.hrcertificates:[]));
        this.tempStorage.setItem(tempContext.srfsessionkey+'_hrcontracts',JSON.stringify(res.data.hrcontracts?res.data.hrcontracts:[]));
        this.tempStorage.setItem(tempContext.srfsessionkey+'_hrdistributions',JSON.stringify(res.data.hrdistributions?res.data.hrdistributions:[]));
        this.tempStorage.setItem(tempContext.srfsessionkey+'_hreducations',JSON.stringify(res.data.hreducations?res.data.hreducations:[]));
        this.tempStorage.setItem(tempContext.srfsessionkey+'_hrfamilies',JSON.stringify(res.data.hrfamilies?res.data.hrfamilies:[]));
        this.tempStorage.setItem(tempContext.srfsessionkey+'_hrlanguageabilities',JSON.stringify(res.data.hrlanguageabilities?res.data.hrlanguageabilities:[]));
        this.tempStorage.setItem(tempContext.srfsessionkey+'_hrpapers',JSON.stringify(res.data.hrpapers?res.data.hrpapers:[]));
        this.tempStorage.setItem(tempContext.srfsessionkey+'_hrpatents',JSON.stringify(res.data.hrpatents?res.data.hrpatents:[]));
        this.tempStorage.setItem(tempContext.srfsessionkey+'_hrresearches',JSON.stringify(res.data.hrresearches?res.data.hrresearches:[]));
        this.tempStorage.setItem(tempContext.srfsessionkey+'_hrrewards',JSON.stringify(res.data.hrrewards?res.data.hrrewards:[]));
        this.tempStorage.setItem(tempContext.srfsessionkey+'_hrtechnicaltitles',JSON.stringify(res.data.hrtechnicaltitles?res.data.hrtechnicaltitles:[]));
        this.tempStorage.setItem(tempContext.srfsessionkey+'_hrtrainingrecords',JSON.stringify(res.data.hrtrainingrecords?res.data.hrtrainingrecords:[]));
        this.tempStorage.setItem(tempContext.srfsessionkey+'_hrtransferapplies',JSON.stringify(res.data.hrtransferapplies?res.data.hrtransferapplies:[]));
        this.tempStorage.setItem(tempContext.srfsessionkey+'_hrworkrecords',JSON.stringify(res.data.hrworkrecords?res.data.hrworkrecords:[]));
        
        return res;
    }

    /**
     * Update接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HREmployeeServiceBase
     */
    public async Update(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let masterData:any = {};
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().put(`/hremployees/${context.hremployee}`,data,isloading);
            
            return res;
    }

    /**
     * Remove接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HREmployeeServiceBase
     */
    public async Remove(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            let res:any = Http.getInstance().delete(`/hremployees/${context.hremployee}`,isloading);
            return res;
    }

    /**
     * Get接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HREmployeeServiceBase
     */
    public async Get(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            let res:any = await Http.getInstance().get(`/hremployees/${context.hremployee}`,isloading);
            
            return res;
    }

    /**
     * GetDraft接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HREmployeeServiceBase
     */
    public async GetDraft(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let res:any = await  Http.getInstance().get(`/hremployees/getdraft`,isloading);
        res.data.hremployee = data.hremployee;
        
        return res;
    }

    /**
     * CheckKey接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HREmployeeServiceBase
     */
    public async CheckKey(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            let res:any = Http.getInstance().post(`/hremployees/${context.hremployee}/checkkey`,data,isloading);
            return res;
    }

    /**
     * Save接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HREmployeeServiceBase
     */
    public async Save(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let masterData:any = {};
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().post(`/hremployees/${context.hremployee}/save`,data,isloading);
            
            return res;
    }

    /**
     * FetchAfterProbation接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HREmployeeServiceBase
     */
    public async FetchAfterProbation(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        let res:any = Http.getInstance().get(`/hremployees/fetchafterprobation`,tempData,isloading);
        return res;
    }

    /**
     * FetchDefault接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HREmployeeServiceBase
     */
    public async FetchDefault(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        let res:any = Http.getInstance().get(`/hremployees/fetchdefault`,tempData,isloading);
        return res;
    }

    /**
     * FetchLeaveDuty接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HREmployeeServiceBase
     */
    public async FetchLeaveDuty(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        let res:any = Http.getInstance().get(`/hremployees/fetchleaveduty`,tempData,isloading);
        return res;
    }

    /**
     * FetchNoContract接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HREmployeeServiceBase
     */
    public async FetchNoContract(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        let res:any = Http.getInstance().get(`/hremployees/fetchnocontract`,tempData,isloading);
        return res;
    }

    /**
     * FetchOnDuty接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HREmployeeServiceBase
     */
    public async FetchOnDuty(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        let res:any = Http.getInstance().get(`/hremployees/fetchonduty`,tempData,isloading);
        return res;
    }

    /**
     * FetchWaitDuty接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HREmployeeServiceBase
     */
    public async FetchWaitDuty(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        let res:any = Http.getInstance().get(`/hremployees/fetchwaitduty`,tempData,isloading);
        return res;
    }
}